<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE" sourcelanguage="en">
<context>
    <name>ActionShowStashDelegate</name>
    <message>
        <source>Application tray</source>
        <translation>App-Palette</translation>
    </message>
</context>
<context>
    <name>ActionToggleCollapseDelegate</name>
    <message>
        <source>Collapse tray</source>
        <translation>Leiste aus-/einfahren</translation>
    </message>
</context>
<context>
    <name>PanelTrayItem</name>
    <message>
        <source>Quick actions</source>
        <translation>Schnelleinsteller</translation>
    </message>
</context>
</TS>